==> opencart-4.1.0.0.zip: upload/admin/language/fr-fr/catalog/manufacturer.php <==
<?php
// Heading
$_['heading_title']           = 'Fabricants';

// Text
$_['text_success']            = 'Succès: Vous avez modifié les fabricants!';
$_['text_list']               = 'Liste des Fabricants';
$_['text_add']                = 'Ajouter un Fabricant';
$_['text_edit']               = 'Modifier le Fabricant';
$_['text_default']            = 'Par Défaut';
$_['text_keyword']            = 'N\'utilisez pas d\'espaces, remplacez plutôt les espaces par - et assurez-vous que l\'URL SEO soit unique à l\'échelle mondiale.';

// Column
$_['column_name']             = 'Nom du Fabricant';
$_['column_sort_order']       = 'Ordre de Tri';
$_['column_action']           = 'Action';

// Entry
$_['entry_name']              = 'Nom du Fabricant';
$_['entry_store']             = 'Magasins';
$_['entry_keyword']           = 'Mot-clé';
$_['entry_image']             = 'Image';
$_['entry_sort_order']        = 'Ordre de Tri';
$_['entry_layout']            = 'Remplacement de la Disposition';

// Error
$_['error_warning']           = 'Attention: Veuillez vérifier le formulaire attentivement pour les erreurs!';
$_['error_permission']        = 'Attention: Vous n\'avez pas la permission de modifier les fabricants!';
$_['error_name']              = 'Le nom du fabricant doit contenir entre 1 et 64 caractères!';
$_['error_keyword']           = 'L\'URL SEO doit contenir entre 1 et 64 caractères!';
$_['error_keyword_exists']    = 'L\'URL SEO doit être unique!';
$_['error_keyword_character'] = 'Le mot-clé ne peut utiliser que les caractères a-z, 0-9, - et _ !';
$_['error_product']           = 'Attention: Ce fabricant ne peut pas être supprimé car il est actuellement assigné à %s produits!';

==> opencart-4.1.0.3.zip: upload/admin/language/fr-fr/catalog/manufacturer.php <==
<?php
// En-tête
$_['heading_title']           = 'Fabricants';

// Texte
$_['text_success']            = 'Succès: Vous avez modifié les fabricants!';
$_['text_list']               = 'Liste des Fabricants';
$_['text_add']                = 'Ajouter un Fabricant';
$_['text_edit']               = 'Modifier le Fabricant';
$_['text_default']            = 'Par Défaut';
$_['text_keyword']            = 'N\'utilisez pas d\'espaces, remplacez plutôt les espaces par - et assurez-vous que l\'URL SEO soit unique à l\'échelle mondiale.';

// Colonne
$_['column_image']            = 'Image';
$_['column_name']             = 'Nom du Fabricant';
$_['column_sort_order']       = 'Ordre de Tri';
$_['column_action']           = 'Action';

// Entrée
$_['entry_name']              = 'Nom du Fabricant';
$_['entry_store']             = 'Magasins';
$_['entry_keyword']           = 'Mot-clé';
$_['entry_image']             = 'Image';
$_['entry_sort_order']        = 'Ordre de Tri';
$_['entry_layout']            = 'Remplacement de la Disposition';

// Erreur
$_['error_warning']           = 'Attention: Veuillez vérifier le formulaire attentivement pour les erreurs!';
$_['error_permission']        = 'Attention: Vous n\'avez pas la permission de modifier les fabricants!';
$_['error_name']              = 'Le nom du fabricant doit contenir entre 1 et 64 caractères!';
$_['error_keyword']           = 'L\'URL SEO doit contenir entre 1 et 64 caractères!';
$_['error_keyword_exists']    = 'L\'URL SEO doit être unique!';
$_['error_keyword_character'] = 'Le mot-clé ne peut utiliser que les caractères a-z, 0-9, - et _ !';
$_['error_product']           = 'Attention: Ce fabricant ne peut pas être supprimé car il est actuellement assigné à %s produits!';
